Module engine

Module engine 

Embedded API surface for the ActionQueue runtime.

Provides ActionQueueEngine as the primary entry point for embedding ActionQueue as a library in Rust applications.

Structs

ActionQueueEngine
Pre-bootstrap engine configuration holder.
BootstrappedEngine
A bootstrapped engine ready for task submission and execution.

Enums

BootstrapError
Errors that can occur during engine bootstrap.
EngineError
Errors that can occur during engine operations.