pub struct ActionQueueEngine<H: ExecutorHandler> { /* private fields */ }Expand description
Pre-bootstrap engine configuration holder.
Implementations
Sourceimpl<H: ExecutorHandler + 'static> ActionQueueEngine<H>
impl<H: ExecutorHandler + 'static> ActionQueueEngine<H>
Sourcepub fn new(config: RuntimeConfig, handler: H) -> Self
pub fn new(config: RuntimeConfig, handler: H) -> Self
Creates a new engine with the given configuration and handler.
Sourcepub fn bootstrap(
self,
) -> Result<BootstrappedEngine<H, SystemClock>, BootstrapError>
pub fn bootstrap( self, ) -> Result<BootstrappedEngine<H, SystemClock>, BootstrapError>
Bootstraps the engine by recovering state from storage and constructing the dispatch loop with the system clock.
Sourcepub fn bootstrap_with_clock<C: Clock>(
self,
clock: C,
) -> Result<BootstrappedEngine<H, C>, BootstrapError>
pub fn bootstrap_with_clock<C: Clock>( self, clock: C, ) -> Result<BootstrappedEngine<H, C>, BootstrapError>
Bootstraps with an explicit clock (for testing).